function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var FLEX_GAP_CSS_VARS;

(function (FLEX_GAP_CSS_VARS) {
  FLEX_GAP_CSS_VARS["FLEX_GAP_OFFSET"] = "--raam-fg-offset";
  FLEX_GAP_CSS_VARS["FLEX_GAP"] = "--raam-fg";
  FLEX_GAP_CSS_VARS["FLEX_GAP_TOP"] = "--raam-fg-t";
  FLEX_GAP_CSS_VARS["FLEX_GAP_LEFT"] = "--raam-fg-l";
})(FLEX_GAP_CSS_VARS || (FLEX_GAP_CSS_VARS = {}));

// ==============================================
// Polyfill for `.flat()`

const flat = arr => arr.reduce((accumulator, currentValue) => accumulator.concat(Array.isArray(currentValue) ? flat(currentValue) : currentValue), []);

const reset = {
  // @ts-ignore
  boxSizing: "border-box",
  margin: 0,
  // @ts-ignore
  minWidth: 0
};

const hasThemeKey = (theme, key) => !(theme == null) && theme.hasOwnProperty(key);

const getStyleValue = ({
  // @TODO This probably shouldn't be a string type
  property,
  srcValue,
  theme
}) => {
  if (srcValue == null) {
    return undefined;
  }

  const getValue = srcValue.constructor.name === "Object" && Object.values(srcValue)[0] || srcValue;

  if (property === "flexGap") {
    const themedValue = hasThemeKey(theme, "space") && theme.space[getValue] ? theme.space[getValue] : getValue;
    return typeof themedValue === "number" ? `${themedValue}px` : themedValue;
  }

  return getValue;
};

const getBreakpoint = ({
  srcValue,
  index,
  theme
}) => {
  if (srcValue == null) {
    return false;
  }

  const hasSrcValueKey = srcValue.constructor.name === "Object";
  const srcValueKey = hasSrcValueKey && Object.keys(srcValue)[0];

  if (["initial", "_"].includes(srcValueKey) || srcValueKey == null) {
    return false;
  }

  if (index === 0 && hasSrcValueKey === false) {
    return false;
  }

  if (!theme) {
    return srcValueKey;
  }

  if (theme) {
    const themedBreakpointKey = srcValueKey || index; // console.log(themedBreakpointKey);

    return hasThemeKey(theme, "breakpoints") && theme.breakpoints[themedBreakpointKey] ? `@media screen and (min-width: ${theme.breakpoints[typeof themedBreakpointKey === "number" ? themedBreakpointKey - 1 : themedBreakpointKey]})` : srcValueKey;
  }

  return false;
};

const getStyleDeclaration = ({
  property,
  srcValue,
  index,
  theme
}) => {
  const breakpoint = getBreakpoint({
    srcValue,
    index,
    theme
  });
  const value = getStyleValue({
    property,
    srcValue,
    theme
  });

  if (!breakpoint && srcValue == null) {
    return null;
  }

  const polyfill = {
    /**
     * Replace `flexGap` with custom properties.
     * These are toggled off (via `initial`) by the appropriate flex property
     * in the latter step.
     */
    flexGap: {
      [FLEX_GAP_CSS_VARS.FLEX_GAP_TOP]: value,
      [FLEX_GAP_CSS_VARS.FLEX_GAP_LEFT]: value,
      [FLEX_GAP_CSS_VARS.FLEX_GAP_OFFSET]: `calc(${value} * -0.5)`,
      [FLEX_GAP_CSS_VARS.FLEX_GAP]: `calc(${value} * 0.5)`
    }
  }[property] || {
    [property]: value
  };
  const extend = {
    flexDirection: {
      // column
      column: {
        [FLEX_GAP_CSS_VARS.FLEX_GAP_LEFT]: "initial"
      },
      "column-reverse": {
        [FLEX_GAP_CSS_VARS.FLEX_GAP_LEFT]: "initial"
      }
    }[value] || {
      [FLEX_GAP_CSS_VARS.FLEX_GAP_TOP]: "initial"
    },
    flexWrap: {
      // nowrap
      nowrap: {
        [FLEX_GAP_CSS_VARS.FLEX_GAP_OFFSET]: "initial",
        [FLEX_GAP_CSS_VARS.FLEX_GAP]: "initial"
      }
    }[value] || {
      [FLEX_GAP_CSS_VARS.FLEX_GAP_TOP]: "initial",
      [FLEX_GAP_CSS_VARS.FLEX_GAP_LEFT]: "initial"
    }
  }[property] || {};

  const style = _extends({}, polyfill, extend);

  return breakpoint ? {
    [breakpoint]: style
  } : style;
};

const stylePropsToDeclarations = ({
  props,
  theme,
  index: _index = 0,
  depth: _depth = 0
}) => {
  const stylesProps = Object.keys(props).map(property => {
    const value = props[property];

    if (value == null || _depth >= 2) {
      return null;
    }

    if (typeof value === "object" && Object.keys(value).length > 1) {
      return Array.isArray(value) ? value.map((arrayItem, index) => stylePropsToDeclarations({
        depth: _depth + 1,
        index,
        props: {
          [property]: arrayItem
        },
        theme
      })) : Object.keys(value).map(mediaQuery => stylePropsToDeclarations({
        depth: _depth + 1,
        props: {
          [property]: {
            [mediaQuery]: value[mediaQuery]
          }
        },
        theme
      }));
    }

    return getStyleDeclaration({
      index: _index,
      property,
      srcValue: value,
      theme
    });
  }); // @TODO Sort by:
  // 1. --var
  // 2. Block
  // 3. Media Queries

  return flat(stylesProps).filter(item => item);
};

const stylePropsToCSS = (_ref) => {
  let {
    theme
  } = _ref,
      props = _objectWithoutPropertiesLoose(_ref, ["theme"]);

  const styleDeclarations = stylePropsToDeclarations({
    props,
    theme
  });
  const mergeMediaQueries = styleDeclarations.reduce((acc, cv) => {
    const mqKey = Object.keys(cv)[0];
    const mqValue = Object.values(cv)[0];
    const isMq = cv.constructor.name === "Object" && mqKey.substring(0, 6) === "@media" && typeof mqValue !== "undefined" && mqValue.constructor.name === "Object";

    if (isMq) {
      const existing = acc.find(item => Object.keys(item)[0] === mqKey);
      const withoutExisting = acc.filter(item => Object.keys(item)[0] !== mqKey);
      return existing ? [...withoutExisting, {
        [mqKey]: Object.assign(Object.values(existing)[0], mqValue)
      }] : [...acc, ...cv];
    }

    return [...acc, ...cv];
  }, []);
  /**
   * Transform to Style Object
   */

  const styleObject = mergeMediaQueries.reduce((acc, cv) => Object.assign(acc, cv), {});
  return styleObject;
};

const propsWithoutUndefined = obj => Object.keys(obj).reduce((acc, key) => {
  if (obj[key] !== undefined) acc[key] = obj[key];
  return acc;
}, {});

const flexVariants = {
  vStack: {
    gap: "1rem",
    flexDirection: "column",
    flexWrap: "nowrap"
  },
  hStack: {
    gap: "1rem",
    flexDirection: "row",
    flexWrap: "nowrap"
  },
  wrap: {
    gap: "1rem",
    alignItems: "center",
    flexDirection: "row",
    flexWrap: "wrap",
    justifyContent: "flex-start"
  }
};

const flexParent = (_ref2) => {
  let {
    gap: flexGap,
    withoutBaseStyles,
    withoutElementStyles
  } = _ref2,
      props = _objectWithoutPropertiesLoose(_ref2, ["gap", "withoutBaseStyles", "withoutElementStyles"]);

  return _extends({}, withoutBaseStyles && reset, !withoutElementStyles && {
    /**
     * `ul`
     * Override browser defaults
     */
    paddingLeft: 0
  }, {
    display: "flex",
    margin: `var(${FLEX_GAP_CSS_VARS.FLEX_GAP_OFFSET}, initial)`
  }, stylePropsToCSS(_extends({
    flexGap
  }, props)));
};

const flexChild = ({
  flex: _flex = "0 0 auto",
  flexBasis,
  flexGrow,
  flexShrink,
  index: _index2 = 1,
  withoutBaseStyles,
  withoutElementStyles,
  theme
}) => _extends({}, !withoutBaseStyles && reset, !withoutElementStyles && {
  /**
   * `li`
   * Ensure any list-items are rendered without bullets.
   * Adding a zero-width space in the content to prevent VoiceOver disable.
   */
  listStyleType: "none",
  "&:before": {
    position: "absolute",
    content: '"\\200B"'
  }
}, {
  marginTop: `var(${FLEX_GAP_CSS_VARS.FLEX_GAP}, ${_index2 > 0 ? `var(${FLEX_GAP_CSS_VARS.FLEX_GAP_TOP}, initial)` : "initial"})`,
  marginRight: `var(${FLEX_GAP_CSS_VARS.FLEX_GAP}, initial)`,
  marginBottom: `var(${FLEX_GAP_CSS_VARS.FLEX_GAP}, initial)`,
  marginLeft: `var(${FLEX_GAP_CSS_VARS.FLEX_GAP}, ${_index2 > 0 ? `var(${FLEX_GAP_CSS_VARS.FLEX_GAP_LEFT}, initial)` : "initial"})`
}, stylePropsToCSS({
  flex: _flex,
  flexBasis,
  flexGrow,
  flexShrink,
  theme
}));

const useFlex = props => {
  const variant = (props == null ? void 0 : props.variant) || "hStack"; // @TODO Support Responsive Variants

  const propsWithVariant = variant ? _extends({}, flexVariants[variant], props && propsWithoutUndefined(props)) : propsWithoutUndefined(props);
  return {
    parent: () => flexParent(_extends({}, propsWithVariant)),
    child: childProps => flexChild(childProps ? _extends({}, childProps, propsWithVariant) : propsWithVariant)
  };
};

export { FLEX_GAP_CSS_VARS, stylePropsToCSS, useFlex };
//# sourceMappingURL=index.modern.js.map
