(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
  typeof define === 'function' && define.amd ? define(['exports'], factory) :
  (global = global || self, factory(global.raam = {}));
}(this, (function (exports) {
  function _extends() {
    _extends = Object.assign || function (target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i];

        for (var key in source) {
          if (Object.prototype.hasOwnProperty.call(source, key)) {
            target[key] = source[key];
          }
        }
      }

      return target;
    };

    return _extends.apply(this, arguments);
  }

  function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};
    var target = {};
    var sourceKeys = Object.keys(source);
    var key, i;

    for (i = 0; i < sourceKeys.length; i++) {
      key = sourceKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      target[key] = source[key];
    }

    return target;
  }

  (function (FLEX_GAP_CSS_VARS) {
    FLEX_GAP_CSS_VARS["FLEX_GAP_OFFSET"] = "--raam-fg-offset";
    FLEX_GAP_CSS_VARS["FLEX_GAP"] = "--raam-fg";
    FLEX_GAP_CSS_VARS["FLEX_GAP_TOP"] = "--raam-fg-t";
    FLEX_GAP_CSS_VARS["FLEX_GAP_LEFT"] = "--raam-fg-l";
  })(exports.FLEX_GAP_CSS_VARS || (exports.FLEX_GAP_CSS_VARS = {}));

  // ==============================================
  // Polyfill for `.flat()`

  var flat = function flat(arr) {
    return arr.reduce(function (accumulator, currentValue) {
      return accumulator.concat(Array.isArray(currentValue) ? flat(currentValue) : currentValue);
    }, []);
  };

  var reset = {
    // @ts-ignore
    boxSizing: "border-box",
    margin: 0,
    // @ts-ignore
    minWidth: 0
  };

  var hasThemeKey = function hasThemeKey(theme, key) {
    return !(theme == null) && theme.hasOwnProperty(key);
  };

  var getStyleValue = function getStyleValue(_ref) {
    var property = _ref.property,
        srcValue = _ref.srcValue,
        theme = _ref.theme;

    if (srcValue == null) {
      return undefined;
    }

    var getValue = srcValue.constructor.name === "Object" && Object.values(srcValue)[0] || srcValue;

    if (property === "flexGap") {
      var themedValue = hasThemeKey(theme, "space") && theme.space[getValue] ? theme.space[getValue] : getValue;
      return typeof themedValue === "number" ? themedValue + "px" : themedValue;
    }

    return getValue;
  };

  var getBreakpoint = function getBreakpoint(_ref2) {
    var srcValue = _ref2.srcValue,
        index = _ref2.index,
        theme = _ref2.theme;

    if (srcValue == null) {
      return false;
    }

    var hasSrcValueKey = srcValue.constructor.name === "Object";
    var srcValueKey = hasSrcValueKey && Object.keys(srcValue)[0];

    if (["initial", "_"].includes(srcValueKey) || srcValueKey == null) {
      return false;
    }

    if (index === 0 && hasSrcValueKey === false) {
      return false;
    }

    if (!theme) {
      return srcValueKey;
    }

    if (theme) {
      var themedBreakpointKey = srcValueKey || index; // console.log(themedBreakpointKey);

      return hasThemeKey(theme, "breakpoints") && theme.breakpoints[themedBreakpointKey] ? "@media screen and (min-width: " + theme.breakpoints[typeof themedBreakpointKey === "number" ? themedBreakpointKey - 1 : themedBreakpointKey] + ")" : srcValueKey;
    }

    return false;
  };

  var getStyleDeclaration = function getStyleDeclaration(_ref3) {
    var _flexGap, _ref4, _column, _columnReverse, _ref5, _nowrap, _ref6, _ref7;

    var property = _ref3.property,
        srcValue = _ref3.srcValue,
        index = _ref3.index,
        theme = _ref3.theme;
    var breakpoint = getBreakpoint({
      srcValue: srcValue,
      index: index,
      theme: theme
    });
    var value = getStyleValue({
      property: property,
      srcValue: srcValue,
      theme: theme
    });

    if (!breakpoint && srcValue == null) {
      return null;
    }

    var polyfill = {
      /**
       * Replace `flexGap` with custom properties.
       * These are toggled off (via `initial`) by the appropriate flex property
       * in the latter step.
       */
      flexGap: (_flexGap = {}, _flexGap[exports.FLEX_GAP_CSS_VARS.FLEX_GAP_TOP] = value, _flexGap[exports.FLEX_GAP_CSS_VARS.FLEX_GAP_LEFT] = value, _flexGap[exports.FLEX_GAP_CSS_VARS.FLEX_GAP_OFFSET] = "calc(" + value + " * -0.5)", _flexGap[exports.FLEX_GAP_CSS_VARS.FLEX_GAP] = "calc(" + value + " * 0.5)", _flexGap)
    }[property] || (_ref4 = {}, _ref4[property] = value, _ref4);
    var extend = {
      flexDirection: {
        // column
        column: (_column = {}, _column[exports.FLEX_GAP_CSS_VARS.FLEX_GAP_LEFT] = "initial", _column),
        "column-reverse": (_columnReverse = {}, _columnReverse[exports.FLEX_GAP_CSS_VARS.FLEX_GAP_LEFT] = "initial", _columnReverse)
      }[value] || (_ref5 = {}, _ref5[exports.FLEX_GAP_CSS_VARS.FLEX_GAP_TOP] = "initial", _ref5),
      flexWrap: {
        // nowrap
        nowrap: (_nowrap = {}, _nowrap[exports.FLEX_GAP_CSS_VARS.FLEX_GAP_OFFSET] = "initial", _nowrap[exports.FLEX_GAP_CSS_VARS.FLEX_GAP] = "initial", _nowrap)
      }[value] || (_ref6 = {}, _ref6[exports.FLEX_GAP_CSS_VARS.FLEX_GAP_TOP] = "initial", _ref6[exports.FLEX_GAP_CSS_VARS.FLEX_GAP_LEFT] = "initial", _ref6)
    }[property] || {};

    var style = _extends({}, polyfill, extend);

    return breakpoint ? (_ref7 = {}, _ref7[breakpoint] = style, _ref7) : style;
  };

  var stylePropsToDeclarations = function stylePropsToDeclarations(_ref8) {
    var props = _ref8.props,
        theme = _ref8.theme,
        _ref8$index = _ref8.index,
        index = _ref8$index === void 0 ? 0 : _ref8$index,
        _ref8$depth = _ref8.depth,
        depth = _ref8$depth === void 0 ? 0 : _ref8$depth;
    var stylesProps = Object.keys(props).map(function (property) {
      var value = props[property];

      if (value == null || depth >= 2) {
        return null;
      }

      if (typeof value === "object" && Object.keys(value).length > 1) {
        return Array.isArray(value) ? value.map(function (arrayItem, index) {
          var _props;

          return stylePropsToDeclarations({
            depth: depth + 1,
            index: index,
            props: (_props = {}, _props[property] = arrayItem, _props),
            theme: theme
          });
        }) : Object.keys(value).map(function (mediaQuery) {
          var _property, _props2;

          return stylePropsToDeclarations({
            depth: depth + 1,
            props: (_props2 = {}, _props2[property] = (_property = {}, _property[mediaQuery] = value[mediaQuery], _property), _props2),
            theme: theme
          });
        });
      }

      return getStyleDeclaration({
        index: index,
        property: property,
        srcValue: value,
        theme: theme
      });
    }); // @TODO Sort by:
    // 1. --var
    // 2. Block
    // 3. Media Queries

    return flat(stylesProps).filter(function (item) {
      return item;
    });
  };

  var stylePropsToCSS = function stylePropsToCSS(_ref9) {
    var theme = _ref9.theme,
        props = _objectWithoutPropertiesLoose(_ref9, ["theme"]);

    var styleDeclarations = stylePropsToDeclarations({
      props: props,
      theme: theme
    });
    var mergeMediaQueries = styleDeclarations.reduce(function (acc, cv) {
      var mqKey = Object.keys(cv)[0];
      var mqValue = Object.values(cv)[0];
      var isMq = cv.constructor.name === "Object" && mqKey.substring(0, 6) === "@media" && typeof mqValue !== "undefined" && mqValue.constructor.name === "Object";

      if (isMq) {
        var _ref10;

        var existing = acc.find(function (item) {
          return Object.keys(item)[0] === mqKey;
        });
        var withoutExisting = acc.filter(function (item) {
          return Object.keys(item)[0] !== mqKey;
        });
        return existing ? [].concat(withoutExisting, [(_ref10 = {}, _ref10[mqKey] = Object.assign(Object.values(existing)[0], mqValue), _ref10)]) : [].concat(acc, cv);
      }

      return [].concat(acc, cv);
    }, []);
    /**
     * Transform to Style Object
     */

    var styleObject = mergeMediaQueries.reduce(function (acc, cv) {
      return Object.assign(acc, cv);
    }, {});
    return styleObject;
  };

  var propsWithoutUndefined = function propsWithoutUndefined(obj) {
    return Object.keys(obj).reduce(function (acc, key) {
      if (obj[key] !== undefined) acc[key] = obj[key];
      return acc;
    }, {});
  };

  var flexVariants = {
    vStack: {
      gap: "1rem",
      flexDirection: "column",
      flexWrap: "nowrap"
    },
    hStack: {
      gap: "1rem",
      flexDirection: "row",
      flexWrap: "nowrap"
    },
    wrap: {
      gap: "1rem",
      alignItems: "center",
      flexDirection: "row",
      flexWrap: "wrap",
      justifyContent: "flex-start"
    }
  };

  var flexParent = function flexParent(_ref11) {
    var flexGap = _ref11.gap,
        withoutBaseStyles = _ref11.withoutBaseStyles,
        withoutElementStyles = _ref11.withoutElementStyles,
        props = _objectWithoutPropertiesLoose(_ref11, ["gap", "withoutBaseStyles", "withoutElementStyles"]);

    return _extends({}, withoutBaseStyles && reset, !withoutElementStyles && {
      /**
       * `ul`
       * Override browser defaults
       */
      paddingLeft: 0
    }, {
      display: "flex",
      margin: "var(" + exports.FLEX_GAP_CSS_VARS.FLEX_GAP_OFFSET + ", initial)"
    }, stylePropsToCSS(_extends({
      flexGap: flexGap
    }, props)));
  };

  var flexChild = function flexChild(_ref12) {
    var _ref12$flex = _ref12.flex,
        flex = _ref12$flex === void 0 ? "0 0 auto" : _ref12$flex,
        flexBasis = _ref12.flexBasis,
        flexGrow = _ref12.flexGrow,
        flexShrink = _ref12.flexShrink,
        _ref12$index = _ref12.index,
        index = _ref12$index === void 0 ? 1 : _ref12$index,
        withoutBaseStyles = _ref12.withoutBaseStyles,
        withoutElementStyles = _ref12.withoutElementStyles,
        theme = _ref12.theme;
    return _extends({}, !withoutBaseStyles && reset, !withoutElementStyles && {
      /**
       * `li`
       * Ensure any list-items are rendered without bullets.
       * Adding a zero-width space in the content to prevent VoiceOver disable.
       */
      listStyleType: "none",
      "&:before": {
        position: "absolute",
        content: '"\\200B"'
      }
    }, {
      marginTop: "var(" + exports.FLEX_GAP_CSS_VARS.FLEX_GAP + ", " + (index > 0 ? "var(" + exports.FLEX_GAP_CSS_VARS.FLEX_GAP_TOP + ", initial)" : "initial") + ")",
      marginRight: "var(" + exports.FLEX_GAP_CSS_VARS.FLEX_GAP + ", initial)",
      marginBottom: "var(" + exports.FLEX_GAP_CSS_VARS.FLEX_GAP + ", initial)",
      marginLeft: "var(" + exports.FLEX_GAP_CSS_VARS.FLEX_GAP + ", " + (index > 0 ? "var(" + exports.FLEX_GAP_CSS_VARS.FLEX_GAP_LEFT + ", initial)" : "initial") + ")"
    }, stylePropsToCSS({
      flex: flex,
      flexBasis: flexBasis,
      flexGrow: flexGrow,
      flexShrink: flexShrink,
      theme: theme
    }));
  };

  var useFlex = function useFlex(props) {
    var variant = (props == null ? void 0 : props.variant) || "hStack"; // @TODO Support Responsive Variants

    var propsWithVariant = variant ? _extends({}, flexVariants[variant], props && propsWithoutUndefined(props)) : propsWithoutUndefined(props);
    return {
      parent: function parent() {
        return flexParent(_extends({}, propsWithVariant));
      },
      child: function child(childProps) {
        return flexChild(childProps ? _extends({}, childProps, propsWithVariant) : propsWithVariant);
      }
    };
  };

  exports.stylePropsToCSS = stylePropsToCSS;
  exports.useFlex = useFlex;

})));
//# sourceMappingURL=index.umd.js.map
