export declare enum FLEX_GAP_CSS_VARS {
    FLEX_GAP_OFFSET = "--raam-fg-offset",
    FLEX_GAP = "--raam-fg",
    FLEX_GAP_TOP = "--raam-fg-t",
    FLEX_GAP_LEFT = "--raam-fg-l"
}
/**
 * CSS Style Object
 */
export declare type RaamCSS = CSSProperties | {
    [
        /**
         * **CSS Selector**
         *
         * @see https://developer.mozilla.org/en-US/docs/Web/CSS/CSS_Selectors
         */
        selector: string]: RaamCSS;
};
declare type RaamStyleProp<K extends keyof CSSProperties, T = void> = CSSProperties[K] | T | {
    [
        /**
         * A **`@media`** CSS at-rule can be used to apply the property based on
         * the result of one or more media queries. With it, you specify a media
         * query and a style value to apply to the document if and only if the
         * media query matches the device on which the content is being used.
         *
         * **Syntax**: `{ <media-query>: <value> }`
         *
         * **Example**: `{ "@media (min-width: 520px)": "1rem" }`
         *
         * @see https://developer.mozilla.org/en-US/docs/Web/CSS/@media
         */
        mediaQuery: string]: CSSProperties[K] | T;
};
declare type RaamStylePropsAll<T = void> = {
    [K in keyof CSSProperties]: RaamStyleProp<K, T> | RaamStyleProp<K, T>[];
};
/**
 * Responsive Style Props
 */
export interface RaamStyleProps extends RaamStylePropsAll {
}
/**
 * Default RaamTheme
 */
declare type ResponsiveThemeValue = StringNumberArr | {
    [key: string]: StringNumber;
};
export interface RaamTheme {
    breakpoints?: ResponsiveThemeValue;
    space?: ResponsiveThemeValue;
}
/**
 * Allow `string` fallbacks without breaking autocomplete
 */
declare type String = string & {};
/**
 * Allow `number` fallbacks without breaking autocomplete
 */
declare type Number = number & {};
declare type StringNumber = string | number;
declare type StringNumberArr = StringNumber | StringNumber[];
declare type Globals = "-moz-initial" | "inherit" | "initial" | "revert" | "unset";
declare type GlobalsNumber = Globals | Number;
declare type ContentDistribution = "space-around" | "space-between" | "space-evenly" | "stretch";
declare type ContentPosition = "center" | "end" | "flex-end" | "flex-start" | "start";
declare type DisplayInside = "-ms-flexbox" | "-ms-grid" | "-webkit-flex" | "flex" | "flow" | "flow-root" | "grid" | "ruby" | "table";
declare type DisplayInternal = "ruby-base" | "ruby-base-container" | "ruby-text" | "ruby-text-container" | "table-caption" | "table-cell" | "table-column" | "table-column-group" | "table-footer-group" | "table-header-group" | "table-row" | "table-row-group";
declare type DisplayLegacy = "-ms-inline-flexbox" | "-ms-inline-grid" | "-webkit-inline-flex" | "inline-block" | "inline-flex" | "inline-grid" | "inline-list-item" | "inline-table";
declare type DisplayOutside = "block" | "inline" | "run-in";
declare type Quote = "close-quote" | "no-close-quote" | "no-open-quote" | "open-quote";
declare type SpacingProperty = Globals | "auto" | String | Number;
declare type SelfPosition = "center" | "end" | "flex-end" | "flex-start" | "self-end" | "self-start" | "start";
interface CSSProperties {
    /**
     * The CSS **`align-items`** property sets the `align-self` value on all direct children as a group. The align-self property sets the alignment of an item within its containing block. In Flexbox it controls the alignment of items on the Cross Axis, in Grid Layout it controls the alignment of items on the Block Axis within their grid area.
     *
     * **Syntax**: `normal | stretch | <baseline-position> | [ <overflow-position>? <self-position> ]`
     *
     * **Initial value**: `normal`
     *
     * ---
     *
     * _Supported in Flex Layout_
     *
     * |  Chrome  | Firefox | Safari  |  Edge  |   IE   |
     * | :------: | :-----: | :-----: | :----: | :----: |
     * |  **52**  | **20**  |  **9**  | **12** | **11** |
     * | 21 _-x-_ |         | 7 _-x-_ |        |        |
     *
     * ---
     *
     * _Supported in Grid Layout_
     *
     * | Chrome | Firefox |  Safari  |  Edge  | IE  |
     * | :----: | :-----: | :------: | :----: | :-: |
     * | **57** | **52**  | **10.1** | **16** | No  |
     *
     * ---
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/align-items
     */
    alignItems?: Globals | SelfPosition | "baseline" | "normal" | "stretch" | String;
    /**
     * The CSS **`align-content`** property sets how the browser distributes space between and around content items along the cross-axis of a flexbox container, and the main-axis of a grid container.
     *
     * **Syntax**: `normal | <baseline-position> | <content-distribution> | <overflow-position>? <content-position>`
     *
     * **Initial value**: `normal`
     *
     * ---
     *
     * _Supported in Flex Layout_
     *
     * |  Chrome  | Firefox |  Safari   |  Edge  |   IE   |
     * | :------: | :-----: | :-------: | :----: | :----: |
     * |  **29**  | **28**  |   **9**   | **12** | **11** |
     * | 21 _-x-_ |         | 6.1 _-x-_ |        |        |
     *
     * ---
     *
     * _Supported in Grid Layout_
     *
     * | Chrome | Firefox |  Safari  |  Edge  | IE  |
     * | :----: | :-----: | :------: | :----: | :-: |
     * | **57** | **52**  | **10.1** | **16** | No  |
     *
     * ---
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/align-content
     */
    alignContent?: Globals | ContentDistribution | ContentPosition | "baseline" | "normal" | String;
    /**
     * The **`content`** CSS property replaces an element with a generated value. Objects inserted using the `content` property are _anonymous replaced elements._
     *
     * **Syntax**: `normal | none | [ <content-replacement> | <content-list> ] [/ <string> ]?`
     *
     * **Initial value**: `normal`
     *
     * | Chrome | Firefox | Safari |  Edge  |  IE   |
     * | :----: | :-----: | :----: | :----: | :---: |
     * | **1**  |  **1**  | **1**  | **12** | **8** |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/content
     */
    content?: Globals | Quote | "contents" | "none" | "normal" | String;
    /**
     * The **`display`** CSS property defines the _display type_ of an element, which consists of the two basic qualities of how an element generates boxes — the **outer display type** defining how the box participates in flow layout, and the **inner display type** defining how the children of the box are laid out.
     *
     * **Syntax**: `[ <display-outside> || <display-inside> ] | <display-listitem> | <display-internal> | <display-box> | <display-legacy>`
     *
     * **Initial value**: `inline`
     *
     * | Chrome | Firefox | Safari |  Edge  |  IE   |
     * | :----: | :-----: | :----: | :----: | :---: |
     * | **1**  |  **1**  | **1**  | **12** | **4** |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/display
     */
    display?: Globals | DisplayOutside | DisplayInside | DisplayInternal | DisplayLegacy | "contents" | "list-item" | "none" | String;
    /**
     * The **`flex-direction`** CSS property sets how flex items are placed in the flex container defining the main axis and the direction (normal or reversed).
     *
     * **Syntax**: `row | row-reverse | column | column-reverse`
     *
     * **Initial value**: `row`
     *
     * |  Chrome  | Firefox | Safari  |  Edge  |    IE    |
     * | :------: | :-----: | :-----: | :----: | :------: |
     * |  **29**  | **20**  |  **9**  | **12** |  **11**  |
     * | 21 _-x-_ |         | 7 _-x-_ |        | 10 _-x-_ |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/flex-direction
     */
    flexDirection?: Globals | "column" | "column-reverse" | "row" | "row-reverse" | String;
    /**
     * The **`flex-wrap`** CSS property sets whether flex items are forced onto one line or can wrap onto multiple lines. If wrapping is allowed, it sets the direction that lines are stacked.
     *
     * **Syntax**: `nowrap | wrap | wrap-reverse`
     *
     * **Initial value**: `nowrap`
     *
     * |  Chrome  | Firefox |  Safari   |  Edge  |   IE   |
     * | :------: | :-----: | :-------: | :----: | :----: |
     * |  **29**  | **28**  |   **9**   | **12** | **11** |
     * | 21 _-x-_ |         | 6.1 _-x-_ |        |        |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/flex-wrap
     */
    flexWrap?: Globals | "nowrap" | "wrap" | "wrap-reverse" | String;
    /**
     * The **`gap`** CSS property sets the gaps (gutters) between rows and columns. It is a shorthand for `row-gap` and `column-gap`.
     *
     * **Syntax**: `<'row-gap'> <'column-gap'>?`
     *
     * ---
     *
     * _Supported in Flex Layout_
     *
     * | Chrome | Firefox | Safari | Edge | IE  |
     * | :----: | :-----: | :----: | :--: | :-: |
     * |   No   | **63**  |   No   |  No  | No  |
     *
     * ---
     *
     * _Supported in Grid Layout_
     *
     * |     Chrome      |     Firefox     |        Safari         |  Edge  | IE  |
     * | :-------------: | :-------------: | :-------------------: | :----: | :-: |
     * |     **66**      |     **61**      | **10.1** _(grid-gap)_ | **16** | No  |
     * | 57 _(grid-gap)_ | 52 _(grid-gap)_ |                       |        |     |
     *
     * ---
     *
     * _Supported in Multi-column Layout_
     *
     * | Chrome | Firefox | Safari |  Edge  | IE  |
     * | :----: | :-----: | :----: | :----: | :-: |
     * | **66** | **61**  |   No   | **16** | No  |
     *
     * ---
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/gap
     */
    gap?: Globals | "normal" | String | Number;
    /**
     * The **`list-style-type`** CSS property sets the marker (such as a disc, character, or custom counter style) of a list item element.
     *
     * **Syntax**: `<counter-style> | <string> | none`
     *
     * **Initial value**: `disc`
     *
     * | Chrome | Firefox | Safari |  Edge  |  IE   |
     * | :----: | :-----: | :----: | :----: | :---: |
     * | **1**  |  **1**  | **1**  | **12** | **4** |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/list-style-type
     */
    listStyleType?: Globals | "none" | String;
    /**
     * The **`margin`** CSS property sets the margin area on all four sides of an element. It is a shorthand for `margin-top`, `margin-right`, `margin-bottom`, and `margin-left`.
     *
     * **Syntax**: `[ <length> | <percentage> | auto ]{1,4}`
     *
     * | Chrome | Firefox | Safari |  Edge  |  IE   |
     * | :----: | :-----: | :----: | :----: | :---: |
     * | **1**  |  **1**  | **1**  | **12** | **3** |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/margin
     */
    margin?: SpacingProperty;
    /**
     * The **`margin-top`** CSS property sets the margin area on the top of an element. A positive value places it farther from its neighbors, while a negative value places it closer.
     *
     * **Syntax**: `<length> | <percentage> | auto`
     *
     * **Initial value**: `0`
     *
     * | Chrome | Firefox | Safari |  Edge  |  IE   |
     * | :----: | :-----: | :----: | :----: | :---: |
     * | **1**  |  **1**  | **1**  | **12** | **3** |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/margin-top
     */
    marginTop?: SpacingProperty;
    /**
     * The **`margin-right`** CSS property sets the margin area on the right side of an element. A positive value places it farther from its neighbors, while a negative value places it closer.
     *
     * **Syntax**: `<length> | <percentage> | auto`
     *
     * **Initial value**: `0`
     *
     * | Chrome | Firefox | Safari |  Edge  |  IE   |
     * | :----: | :-----: | :----: | :----: | :---: |
     * | **1**  |  **1**  | **1**  | **12** | **3** |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/margin-right
     */
    marginRight?: SpacingProperty;
    /**
     * The **`margin-bottom`** CSS property sets the margin area on the bottom of an element. A positive value places it farther from its neighbors, while a negative value places it closer.
     *
     * **Syntax**: `<length> | <percentage> | auto`
     *
     * **Initial value**: `0`
     *
     * | Chrome | Firefox | Safari |  Edge  |  IE   |
     * | :----: | :-----: | :----: | :----: | :---: |
     * | **1**  |  **1**  | **1**  | **12** | **3** |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/margin-bottom
     */
    marginBottom?: SpacingProperty;
    /**
     * The **`margin-left`** CSS property sets the margin area on the left side of an element. A positive value places it farther from its neighbors, while a negative value places it closer.
     *
     * **Syntax**: `<length> | <percentage> | auto`
     *
     * **Initial value**: `0`
     *
     * | Chrome | Firefox | Safari |  Edge  |  IE   |
     * | :----: | :-----: | :----: | :----: | :---: |
     * | **1**  |  **1**  | **1**  | **12** | **3** |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/margin-left
     */
    marginLeft?: SpacingProperty;
    /**
     * The **`padding`** CSS property sets the padding area on all four sides of an element. It is a shorthand for `padding-top`, `padding-right`, `padding-bottom`, and `padding-left`.
     *
     * **Syntax**: `[ <length> | <percentage> ]{1,4}`
     *
     * | Chrome | Firefox | Safari |  Edge  |  IE   |
     * | :----: | :-----: | :----: | :----: | :---: |
     * | **1**  |  **1**  | **1**  | **12** | **4** |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/padding
     */
    padding?: SpacingProperty;
    /**
     * The **`padding-top`** padding area on the top of an element.
     *
     * **Syntax**: `<length> | <percentage>`
     *
     * **Initial value**: `0`
     *
     * | Chrome | Firefox | Safari |  Edge  |  IE   |
     * | :----: | :-----: | :----: | :----: | :---: |
     * | **1**  |  **1**  | **1**  | **12** | **4** |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/padding-top
     */
    paddingTop?: SpacingProperty;
    /**
     * The **`padding-right`** CSS property sets the width of the padding area on the right side of an element.
     *
     * **Syntax**: `<length> | <percentage>`
     *
     * **Initial value**: `0`
     *
     * | Chrome | Firefox | Safari |  Edge  |  IE   |
     * | :----: | :-----: | :----: | :----: | :---: |
     * | **1**  |  **1**  | **1**  | **12** | **4** |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/padding-right
     */
    paddingRight?: SpacingProperty;
    /**
     * The **`padding-bottom`** CSS property sets the height of the padding area on the bottom of an element.
     *
     * **Syntax**: `<length> | <percentage>`
     *
     * **Initial value**: `0`
     *
     * | Chrome | Firefox | Safari |  Edge  |  IE   |
     * | :----: | :-----: | :----: | :----: | :---: |
     * | **1**  |  **1**  | **1**  | **12** | **4** |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/padding-bottom
     */
    paddingBottom?: SpacingProperty;
    /**
     * The **`padding-left`** CSS property sets the width of the padding area on the left side of an element.
     *
     * **Syntax**: `<length> | <percentage>`
     *
     * **Initial value**: `0`
     *
     * | Chrome | Firefox | Safari |  Edge  |  IE   |
     * | :----: | :-----: | :----: | :----: | :---: |
     * | **1**  |  **1**  | **1**  | **12** | **4** |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/padding-left
     */
    paddingLeft?: SpacingProperty;
    /**
     * The **`position`** CSS property sets how an element is positioned in a document. The `top`, `right`, `bottom`, and `left` properties determine the final location of positioned elements.
     *
     * **Syntax**: `static | relative | absolute | sticky | fixed`
     *
     * **Initial value**: `static`
     *
     * | Chrome | Firefox | Safari |  Edge  |  IE   |
     * | :----: | :-----: | :----: | :----: | :---: |
     * | **1**  |  **1**  | **1**  | **12** | **4** |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/position
     */
    position?: Globals | "-webkit-sticky" | "absolute" | "fixed" | "relative" | "static" | "sticky";
    /**
     * The CSS **`justify-content`** property defines how the browser distributes space between and around content items along the main-axis of a flex container, and the inline axis of a grid container.
     *
     * **Syntax**: `normal | <content-distribution> | <overflow-position>? [ <content-position> | left | right ]`
     *
     * **Initial value**: `normal`
     *
     * ---
     *
     * _Supported in Flex Layout_
     *
     * |  Chrome  | Firefox |  Safari   |  Edge  |   IE   |
     * | :------: | :-----: | :-------: | :----: | :----: |
     * |  **52**  | **20**  |   **9**   | **12** | **11** |
     * | 21 _-x-_ |         | 6.1 _-x-_ |        |        |
     *
     * ---
     *
     * _Supported in Grid Layout_
     *
     * | Chrome | Firefox |  Safari  |  Edge  | IE  |
     * | :----: | :-----: | :------: | :----: | :-: |
     * | **57** | **52**  | **10.1** | **16** | No  |
     *
     * ---
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/justify-content
     */
    justifyContent?: Globals | ContentDistribution | ContentPosition | "left" | "normal" | "right" | String;
    /**
     * The CSS **`justify-items`** property defines the default `justify-self` for all items of the box, giving them all a default way of justifying each box along the appropriate axis.
     *
     * **Syntax**: `normal | stretch | <baseline-position> | <overflow-position>? [ <self-position> | left | right ] | legacy | legacy && [ left | right | center ]`
     *
     * **Initial value**: `legacy`
     *
     * ---
     *
     * _Supported in Flex Layout_
     *
     * | Chrome | Firefox | Safari |  Edge  |   IE   |
     * | :----: | :-----: | :----: | :----: | :----: |
     * | **52** | **20**  | **9**  | **12** | **11** |
     *
     * ---
     *
     * _Supported in Grid Layout_
     *
     * | Chrome | Firefox |  Safari  |  Edge  | IE  |
     * | :----: | :-----: | :------: | :----: | :-: |
     * | **57** | **45**  | **10.1** | **16** | No  |
     *
     * ---
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/justify-items
     */
    justifyItems?: Globals | SelfPosition | "baseline" | "left" | "legacy" | "normal" | "right" | "stretch" | String;
    /**
     * The **`flex`** CSS property sets how a flex item will grow or shrink to fit the space available in its flex container. It is a shorthand for `flex-grow`, `flex-shrink`, and `flex-basis`.
     *
     * **Syntax**: `none | [ <'flex-grow'> <'flex-shrink'>? || <'flex-basis'> ]`
     *
     * |  Chrome  | Firefox |  Safari   |  Edge  |    IE    |
     * | :------: | :-----: | :-------: | :----: | :------: |
     * |  **29**  | **20**  |   **9**   | **12** |  **11**  |
     * | 21 _-x-_ |         | 6.1 _-x-_ |        | 10 _-x-_ |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/flex
     */
    flex?: Globals | "auto" | "content" | "max-content" | "min-content" | "none" | String | Number;
    /**
     * The **`flex-grow`** CSS property sets how much of the available space in the flex container should be assigned to that item (the flex grow factor). If all sibling items have the same flex grow factor, then all items will receive the same share of available space, otherwise it is distributed according to the ratio defined by the different flex grow factors.
     *
     * **Syntax**: `<number>`
     *
     * **Initial value**: `0`
     *
     * |  Chrome  | Firefox |  Safari   |  Edge  |            IE            |
     * | :------: | :-----: | :-------: | :----: | :----------------------: |
     * |  **29**  | **20**  |   **9**   | **12** |          **11**          |
     * | 22 _-x-_ |         | 6.1 _-x-_ |        | 10 _(-ms-flex-positive)_ |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/flex-grow
     */
    flexGrow?: GlobalsNumber;
    /**
     * The **`flex-basis`** CSS property sets the initial main size of a flex item. It sets the size of the content box unless otherwise set with `box-sizing`.
     *
     * **Syntax**: `content | <'width'>`
     *
     * **Initial value**: `auto`
     *
     * |  Chrome  | Firefox | Safari  |  Edge  |   IE   |
     * | :------: | :-----: | :-----: | :----: | :----: |
     * |  **29**  | **22**  |  **9**  | **12** | **11** |
     * | 22 _-x-_ |         | 7 _-x-_ |        |        |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/flex-basis
     */
    flexBasis?: Globals | "-moz-max-content" | "-moz-min-content" | "-webkit-auto" | "auto" | "content" | "max-content" | "min-content" | String;
    /**
     * The **`flex-shrink`** CSS property sets the flex shrink factor of a flex item. If the size of flex items is larger than the flex container, items shrink to fit according to `flex-shrink`.
     *
     * **Syntax**: `<number>`
     *
     * **Initial value**: `1`
     *
     * |  Chrome  | Firefox | Safari  |  Edge  |   IE   |
     * | :------: | :-----: | :-----: | :----: | :----: |
     * |  **29**  | **20**  |  **9**  | **12** | **10** |
     * | 22 _-x-_ |         | 8 _-x-_ |        |        |
     *
     * @see https://developer.mozilla.org/docs/Web/CSS/flex-shrink
     */
    flexShrink?: GlobalsNumber;
}
export {};
